
:orphan:

.. _sphx_glr_sg_execution_times:


Computation times
=================
**00:00.114** total execution time for 73 files **from all galleries**:

.. container::

  .. raw:: html

    <style scoped>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/5.3.0/css/bootstrap.min.css" rel="stylesheet" />
    <link href="https://cdn.datatables.net/1.13.6/css/dataTables.bootstrap5.min.css" rel="stylesheet" />
    </style>
    <script src="https://code.jquery.com/jquery-3.7.0.js"></script>
    <script src="https://cdn.datatables.net/1.13.6/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/1.13.6/js/dataTables.bootstrap5.min.js"></script>
    <script type="text/javascript" class="init">
    $(document).ready( function () {
        $('table.sg-datatable').DataTable({order: [[1, 'desc']]});
    } );
    </script>

  .. list-table::
   :header-rows: 1
   :class: table table-striped sg-datatable

   * - Example
     - Time
     - Mem (MB)
   * - :ref:`sphx_glr_gallery_basic_plot_3d.py` (``../../gallery/basic/plot_3d.py``)
     - 00:00.114
     - 0.0
   * - :ref:`sphx_glr_gallery_basic_plot_basic.py` (``../../gallery/basic/plot_basic.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_basic_plot_big_curves.py` (``../../gallery/basic/plot_big_curves.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_basic_plot_dag.py` (``../../gallery/basic/plot_dag.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_basic_plot_directed.py` (``../../gallery/basic/plot_directed.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_basic_plot_grouping.py` (``../../gallery/basic/plot_grouping.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_basic_plot_house.py` (``../../gallery/basic/plot_house.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_basic_plot_loops.py` (``../../gallery/basic/plot_loops.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_basic_plot_simple_path.py` (``../../gallery/basic/plot_simple_path.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_biology_plot_animal_phylogeny.py` (``../../gallery/biology/plot_animal_phylogeny.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_biology_plot_antibody_clone.py` (``../../gallery/biology/plot_antibody_clone.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_biology_plot_breast_cancer_ppi.py` (``../../gallery/biology/plot_breast_cancer_ppi.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_biology_plot_cell_cycle_arrest.py` (``../../gallery/biology/plot_cell_cycle_arrest.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_biology_plot_food_network.py` (``../../gallery/biology/plot_food_network.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_biology_plot_foraging_table.py` (``../../gallery/biology/plot_foraging_table.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_biology_plot_pollinators.py` (``../../gallery/biology/plot_pollinators.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_biology_plot_ppi.py` (``../../gallery/biology/plot_ppi.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_biology_plot_tca_cycle.py` (``../../gallery/biology/plot_tca_cycle.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_network_science_plot_arrowlawn.py` (``../../gallery/network_science/plot_arrowlawn.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_network_science_plot_chess_masters.py` (``../../gallery/network_science/plot_chess_masters.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_network_science_plot_cliques.py` (``../../gallery/network_science/plot_cliques.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_network_science_plot_cluster_layout.py` (``../../gallery/network_science/plot_cluster_layout.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_network_science_plot_company_structure.py` (``../../gallery/network_science/plot_company_structure.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_network_science_plot_complex.py` (``../../gallery/network_science/plot_complex.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_network_science_plot_financial_network.py` (``../../gallery/network_science/plot_financial_network.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_network_science_plot_knuth_miles.py` (``../../gallery/network_science/plot_knuth_miles.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_network_science_plot_labels_and_colors.py` (``../../gallery/network_science/plot_labels_and_colors.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_network_science_plot_max_bipartite_matching.py` (``../../gallery/network_science/plot_max_bipartite_matching.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_network_science_plot_minimum_spanning_trees.py` (``../../gallery/network_science/plot_minimum_spanning_trees.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_network_science_plot_multipartite_layout.py` (``../../gallery/network_science/plot_multipartite_layout.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_network_science_plot_parallel_igraph_networkx.py` (``../../gallery/network_science/plot_parallel_igraph_networkx.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_network_science_plot_redblack.py` (``../../gallery/network_science/plot_redblack.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_network_science_plot_shortest_path.py` (``../../gallery/network_science/plot_shortest_path.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_network_science_plot_simple_networkx.py` (``../../gallery/network_science/plot_simple_networkx.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_network_science_plot_social_network_circles.py` (``../../gallery/network_science/plot_social_network_circles.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_network_science_plot_traveling_salesman.py` (``../../gallery/network_science/plot_traveling_salesman.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_network_science_plot_with_colorbar.py` (``../../gallery/network_science/plot_with_colorbar.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_other_plot_animation.py` (``../../gallery/other/plot_animation.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_other_plot_edit_artists.py` (``../../gallery/other/plot_edit_artists.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_other_plot_feedbacks.py` (``../../gallery/other/plot_feedbacks.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_other_plot_graph.py` (``../../gallery/other/plot_graph.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_other_plot_mouse_hover.py` (``../../gallery/other/plot_mouse_hover.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_other_plot_train.py` (``../../gallery/other/plot_train.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_style_plot_arrows.py` (``../../gallery/style/plot_arrows.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_style_plot_edgepadding.py` (``../../gallery/style/plot_edgepadding.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_style_plot_elements.py` (``../../gallery/style/plot_elements.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_style_plot_four_grids.py` (``../../gallery/style/plot_four_grids.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_style_plot_halfarrows.py` (``../../gallery/style/plot_halfarrows.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_style_plot_multistyle.py` (``../../gallery/style/plot_multistyle.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_style_plot_ports.py` (``../../gallery/style/plot_ports.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_style_plot_style.py` (``../../gallery/style/plot_style.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_style_plot_tension.py` (``../../gallery/style/plot_tension.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_style_plot_vertexmarkers.py` (``../../gallery/style/plot_vertexmarkers.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_style_plot_voronoi.py` (``../../gallery/style/plot_voronoi.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_style_plot_waypoints.py` (``../../gallery/style/plot_waypoints.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_tree_plot_angular_waypoints.py` (``../../gallery/tree/plot_angular_waypoints.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_tree_plot_biopython_tree.py` (``../../gallery/tree/plot_biopython_tree.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_tree_plot_cladeedges.py` (``../../gallery/tree/plot_cladeedges.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_tree_plot_cogent3_layouts.py` (``../../gallery/tree/plot_cogent3_layouts.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_tree_plot_cogent3_tree.py` (``../../gallery/tree/plot_cogent3_tree.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_tree_plot_elements_tree.py` (``../../gallery/tree/plot_elements_tree.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_tree_plot_ete4.py` (``../../gallery/tree/plot_ete4.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_tree_plot_leafedges.py` (``../../gallery/tree/plot_leafedges.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_tree_plot_leafedges_and_cascades.py` (``../../gallery/tree/plot_leafedges_and_cascades.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_tree_plot_skbio_tree.py` (``../../gallery/tree/plot_skbio_tree.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_tree_plot_split_edges.py` (``../../gallery/tree/plot_split_edges.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_tree_plot_style_tree.py` (``../../gallery/tree/plot_style_tree.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_tree_plot_support.py` (``../../gallery/tree/plot_support.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_tree_plot_tree_node_background.py` (``../../gallery/tree/plot_tree_node_background.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_tree_plot_tree_style_clades.py` (``../../gallery/tree/plot_tree_style_clades.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_tree_plot_trees_of_trees.py` (``../../gallery/tree/plot_trees_of_trees.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_zero_dependency_plot_simplenetworkdataprovider.py` (``../../gallery/zero_dependency/plot_simplenetworkdataprovider.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_zero_dependency_plot_simpletreedataprovider.py` (``../../gallery/zero_dependency/plot_simpletreedataprovider.py``)
     - 00:00.000
     - 0.0
